verticalitytools.iterate_vertical_moments_in_expr
=================================================

.. autofunction:: abjad.tools.verticalitytools.iterate_vertical_moments_in_expr.iterate_vertical_moments_in_expr
   :noindex:
